@@ -237,6 +237,22 @@ def loader_for_file(filename):
         return Loader(jobject=loader)
 
 
+def load_any_file(filename):
+    """
+    Determines a Loader based on the the file extension. If successful, loads the full dataset and returns it.
+
+    :param filename: the name of the file to load
+    :type filename: str
+    :return: the
+    :rtype: Instances
+    """
+    loader = loader_for_file(filename)
+    if loader is None:
+        return None
+    else:
+        return loader.load_file(filename)
+
+
 def saver_for_file(filename):
     """
     Returns a Saver that can load the specified file, based on the file extension. None if failed to determine.
@@ -255,6 +271,25 @@ def saver_for_file(filename):
         return Saver(jobject=saver)
 
 
+def save_any_file(data, filename):
+    """
+    Determines a Saver based on the the file extension. Returns whether successfully saved.
+
+    :param filename: the name of the file to save
+    :type filename: str
+    :param data: the data to save
+    :type data: Instances
+    :return: whether successfully saved
+    :rtype: bool
+    """
+    saver = saver_for_file(filename)
+    if saver is None:
+        return False
+    else:
+        saver.save_file(data, filename)
+        return True
+
+
 def ndarray_to_instances(array, relation, att_template="Att-#", att_list=None):
     """
     Converts the numpy matrix into an Instances object and returns it.
